Group: Development/Python
# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-build-python rpm-build-python3
BuildRequires: python-devel python-module-setuptools python3-module-setuptools
# END SourceDeps(oneline)
BuildRequires: python3-tools
BuildRequires: libnumpy-devel
%define oldname python-biopython
%define fedora 32
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
%if 0%{?fedora} || 0%{?rhel} > 7
%global with_python3 1
%endif

# Careful, the releases 1.77+ do not longer support Python 2.
%if 0%{?rhel} && 0%{?rhel} == 7
%global with_python2 1
%endif

%if 0%{?rhel}
%global py2_prefix python
%else
%global py2_prefix python2
%endif

%if 0%{?python3_version_nodots} == 38
%global with_check 1
%else
%global with_check 1
%endif

%global pypi_name biopython
%global module %{pypi_name}

Name:             python-module-biopython
Version:          1.78
Release:          alt2_1
Summary:          Python tools for computational molecular biology
Source0:          %{pypi_name}-%version.tar.gz

# Starting from biopython-1.69, BioPython is released under the
# "Biopython License Agreement"; it looks like a MIT variant
# rhbz #1440337
License:          MIT and BSD
URL:              https://biopython.org/
BuildRequires:    gcc

%if 0%{?with_python3_other}
BuildRequires:  python%{python3_other_pkgversion}-devel
%endif
Source44: import.info

%description
A set of freely available Python tools for computational molecular
biology.

%if 0%{?with_python3}
%package -n python3-module-biopython
Group: Development/Python
Summary: Python3 tools for computational molecular biology

%{?python_provide:%python_provide python%{python3_pkgversion}-%{module}}

BuildRequires:    python3-devel
BuildRequires:    python3-module-distribute
BuildRequires:    python3-module-Reportlab
BuildRequires:    python3-module-numpy python3-module-numpy-testing
BuildRequires:    python3-module-mysqlclient
BuildRequires:    python3-module-psycopg2
BuildRequires:    python3-module-rdflib
BuildRequires:    python3-module-mysql
Requires:         python3-module-networkx-core python3-module-networkx-drawing
Requires:         python3-module-pygraphviz
Requires:         python3-module-mysql
Requires:         python3-module-Reportlab
Requires:         python3-module-numpy python3-module-numpy-testing
Requires:         python3-module-mysqlclient
Requires:         python3-module-psycopg2
Requires:         wise2
Requires:         flex
Requires:         python3-module-rdflib

%description -n python3-module-biopython
A set of freely available Python3 tools for computational molecular
biology.
%endif

%package -n python-module-biopython-doc
Group: Development/Python
Summary: PDF and HTML documentation of %{module}
BuildArch: noarch
%description -n python-module-biopython-doc
PDF/HTML documentation of %{module}.

%prep
%setup -n %{oldname}-%{version} -qc

pushd %{module}-%{version}
# remove all execute bits from documentation and fix line endings
find Scripts -type f -exec chmod -x {} 2>/dev/null ';'
find Doc -type f -exec chmod -x {} 2>/dev/null ';'
find Doc -type f -exec sed -i 's/\r//' {} 2>/dev/null ';'

# remove execute bits from Python modules
find Bio -type f -exec chmod -x {} 2>/dev/null ';'
# remove she-bang lines in .py files to keep rpmlint happy
find Bio -type f -name "*.py" -exec sed -i '/^#![ ]*\/usr\/bin\/.*$/ d' {} 2>/dev/null ';'
popd

%if 0%{?with_python2}
cp -a %{module}-%{version} python2
%endif

%if 0%{?with_python3}
cp -a %{module}-%{version} python3
%endif
# with_python3

%if 0%{?with_python3_other}
cp -a %{module}-%{version} python%{python3_other_pkgversion}
%endif
# with_python3_other

%build
%if 0%{?with_python2}
pushd python2
%python_build
popd
%endif

%if 0%{?with_python3}
pushd python3
%python3_build
popd
%endif
# with_python3

%if 0%{?with_python3_other}
pushd python%{python3_other_pkgversion}
%py3_other_build
popd
%endif
# with_python3_other

%install
%if 0%{?with_python3}
pushd python3
%{__python3} setup.py install -O1 --skip-build --root=$RPM_BUILD_ROOT --install-data=%{_datadir}/python-biopython

find Scripts -name '*.py' | xargs pathfix.py -pn -i "%{__python3}"
popd
%endif

%if 0%{?with_python3_other}
pushd python%{python3_other_pkgversion}
%{__python3_other} setup.py install -O1 --skip-build --root=$RPM_BUILD_ROOT --install-data=%{_datadir}/python-biopython

find Scripts -name '*.py' | xargs pathfix.py -pn -i "%{__python3_other}"
popd
%endif

%if 0%{?with_python2}
pushd python2
%{__python} setup.py install -O1 --skip-build --root=$RPM_BUILD_ROOT --install-data=%{_datadir}/python-biopython

find Scripts -name '*.py' | xargs pathfix.py -pn -i "%{__python}"
popd
%endif

##DocTest cannot be executed
##https://github.com/biopython/biopython/issues/669; http://lists.open-bio.org/pipermail/biopython-dev/2014-May/020541.html
%if 0%{?with_check}
%check
%if 0%{?with_python2}
pushd python2
export PYTHONPATH=$RPM_BUILD_ROOT%{python_sitelibdir}
find . -name 'run_tests.py' | xargs pathfix.py -pn -i "%{__python}"
for test in `ls test_*.py | grep -v Tutorial`; do
%{__python} run_tests.py --offline -v ${test}
done
popd
%endif

# See https://github.com/biopython/biopython/issues/855; https://github.com/biopython/biopython/issues/1889
%if 0%{?with_python3}
pushd python3/Tests
find . -name 'run_tests.py' | xargs pathfix.py -pn -i "%{__python3}"
# See https://github.com/biopython/biopython/issues/2128; https://github.com/biopython/biopython/issues/2120
# and https://bugs.python.org/issue24214
%if 0%{?python3_version_nodots} == 38
echo "Skipping tests under unsupported Python 3.8"
%else
for test in `ls test_*.py | grep -v Nexus | grep -v Phylo | grep -v Tutorial | grep -v bgzf | grep -v SearchIO_blast | grep -v pairwise_aligner | grep -v SubsMat`; do
echo $LANG
export PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitelibdir}
%{__python3} run_tests.py --offline -v ${test}
done
%endif
popd
%endif

# See https://github.com/biopython/biopython/issues/855
%if 0%{?with_python3_other}
pushd python%{python3_other_pkgversion}/Tests
find . -name 'run_tests.py' | xargs pathfix.py -pn -i "%{__python3_other}"
for test in `ls test_*.py | grep -v Nexus | grep -v Phylo | grep -v Tutorial | grep -v bgzf`; do
echo $LANG
export PYTHONPATH=$RPM_BUILD_ROOT%{python3_other_sitearch}
%{__python3_other} run_tests.py --offline -v ${test}
done
popd
%endif
# with_python3_other
%endif
# with_check

%if 0%{?with_python2}
%files -n python-module-biopython
%doc python2/Scripts
%doc python2/CONTRIB.rst python2/DEPRECATED.rst python2/NEWS.rst python2/README.rst
%doc --no-dereference python2/LICENSE.rst
%{python_sitelibdir}/*egg-info
%{python_sitelibdir}/Bio/
%{python_sitelibdir}/BioSQL/
%endif

%if 0%{?with_python3}
%files -n python3-module-biopython
%doc python3/Scripts
%doc python3/CONTRIB.rst python3/DEPRECATED.rst python3/NEWS.rst python3/README.rst
%doc --no-dereference python3/LICENSE.rst
%{python3_sitelibdir}/*egg-info
%{python3_sitelibdir}/Bio/
%{python3_sitelibdir}/BioSQL/
%endif

%if 0%{?with_python3_other}
%files -n python-module-biopython
%doc python%{python3_other_pkgversion}/Scripts
%doc python%{python3_other_pkgversion}/CONTRIB.rst
%doc python%{python3_other_pkgversion}/DEPRECATED.rst
%doc python%{python3_other_pkgversion}/NEWS.rst
%doc python%{python3_other_pkgversion}/README.rst
%doc --no-dereference python%{python3_other_pkgversion}/LICENSE.rst
%{python3_other_sitearch}/*egg-info
%{python3_other_sitearch}/Bio/
%{python3_other_sitearch}/BioSQL/
%endif

%files -n python-module-biopython-doc
%doc %{module}-%{version}/Doc
%doc --no-dereference %{module}-%{version}/LICENSE.rst

%changelog
* Thu Apr 15 2021 Cronbuild Service <cronbuild@altlinux.org> 1.78-alt2_1
- rebuild to get rid of unmets

* Tue Nov 03 2020 Igor Vlasenko <viy@altlinux.ru> 1.78-alt1_1
- update

* Tue Aug 06 2019 Igor Vlasenko <viy@altlinux.ru> 1.73-alt2_6
- update to new release by fcimport

* Fri Apr 19 2019 Cronbuild Service <cronbuild@altlinux.org> 1.73-alt2_2
- rebuild to get rid of unmets

* Sun Mar 10 2019 Igor Vlasenko <viy@altlinux.ru> 1.73-alt1_2
- update to new release by fcimport

* Sun May 20 2018 Igor Vlasenko <viy@altlinux.ru> 1.71-alt1_2
- update to new release by fcimport

* Sat May 05 2018 Cronbuild Service <cronbuild@altlinux.org> 1.70-alt2_11
- rebuild to get rid of unmets

* Thu Mar 08 2018 Igor Vlasenko <viy@altlinux.ru> 1.70-alt1_11
- update to new release by fcimport

* Tue Feb 20 2018 Igor Vlasenko <viy@altlinux.ru> 1.70-alt1_10
- update to new release by fcimport

* Mon Oct 09 2017 Igor Vlasenko <viy@altlinux.ru> 1.70-alt1_3
- update to new release by fcimport

* Mon Sep 21 2015 Igor Vlasenko <viy@altlinux.ru> 1.65-alt1_2
- update to new release by fcimport

* Wed Sep 10 2014 Igor Vlasenko <viy@altlinux.ru> 1.64-alt1_2
- update to new release by fcimport

* Mon Jul 07 2014 Igor Vlasenko <viy@altlinux.ru> 1.64-alt1_1
- update to new release by fcimport

* Mon Sep 02 2013 Igor Vlasenko <viy@altlinux.ru> 1.60-alt1_3
- update to new release by fcimport

* Thu Feb 21 2013 Igor Vlasenko <viy@altlinux.ru> 1.60-alt1_2
- update to new release by fcimport

* Sat Jan 05 2013 Igor Vlasenko <viy@altlinux.ru> 1.60-alt1_1
- initial fc import

